# Core Functions

The main calculation and simulation functions.

## CEFR Calculation

::: fundedness.cefr.compute_cefr

## Monte Carlo Simulation

::: fundedness.simulate.run_simulation

## Strategy Comparison

::: fundedness.withdrawals.comparison.compare_strategies
